from dolmen.app.authentication.plugins.cookies import CookiesCredentials
from dolmen.app.authentication.plugins.globalregistry import GlobalRegistryAuth
from dolmen.app.authentication.plugins.principalfolder import (
    PrincipalFolderPlugin)
